pub struct ConnDag<'a> {
pub conn: &'a Connection,
pub room: &'a str,
}Expand description
The DAG of one room as the core sees it.
Fields
conn: &'a Connectionroom: &'a strTrait Implementations
Sourceimpl DagRead for ConnDag<'_>
impl DagRead for ConnDag<'_>
Sourcefn pdu(&self, id: &EventId) -> Option<Pdu>
fn pdu(&self, id: &EventId) -> Option<Pdu>
A stored event (accepted, soft-failed or imported outlier).
Sourcefn state_after(&self, id: &EventId) -> Option<StateMap<OwnedEventId>>
fn state_after(&self, id: &EventId) -> Option<StateMap<OwnedEventId>>
The room state after the event, for events that have one.
Sourcefn extremities(&self) -> Vec<OwnedEventId>
fn extremities(&self) -> Vec<OwnedEventId>
The room’s forward extremities.