pub fn enqueue_typing(
conn: &Connection,
room_id: &str,
user_id: i64,
typing: bool,
)Expand description
A local user’s typing state in a room that has remote members.
pub fn enqueue_typing(
conn: &Connection,
room_id: &str,
user_id: i64,
typing: bool,
)A local user’s typing state in a room that has remote members.