request_signing_object

Function request_signing_object 

pub fn request_signing_object(
    method: &str,
    uri: &str,
    origin: &str,
    destination: &str,
    content: Option<&Value>,
) -> Value
The object a sender signs for an authenticated federation request. uri is the full path and query as the receiver sees it, including /_matrix.