pub struct MatrixError {
pub status: u16,
pub errcode: &'static str,
pub error: String,
pub retry_after_ms: Option<u64>,
pub soft_logout: Option<bool>,
pub current_version: Option<String>,
}Fields
status: u16errcode: &'static strerror: Stringretry_after_ms: Option<u64>soft_logout: Option<bool>current_version: Option<String>Implementations
Sourceimpl MatrixError
impl MatrixError
pub fn missing_token() -> Self
pub fn unknown_token() -> Self
Federation request authentication failure (M_UNAUTHORIZED, 401).
Sourcepub fn invalid_nick(msg: impl Into<String>) -> Self
pub fn invalid_nick(msg: impl Into<String>) -> Self
Nick fails the grammar or a forbidden list (M4A_INVALID_NICK, 400).
Sourcepub fn nick_taken() -> Self
pub fn nick_taken() -> Self
Nick equals another live nick, a frozen localpart or a reserved one (M4A_NICK_TAKEN, 409).
Sourcepub fn nick_conflict() -> Self
pub fn nick_conflict() -> Self
An issuer asserted a nick that collides with another account’s localpart
(M4A_NICK_CONFLICT, 409). The issuer must pick another nick.
Sourcepub fn nick_cooldown(retry_after_ms: u64) -> Self
pub fn nick_cooldown(retry_after_ms: u64) -> Self
Nick changed too recently (M4A_NICK_COOLDOWN, 429).
Sourcepub fn policy_denied(msg: impl Into<String>) -> Self
pub fn policy_denied(msg: impl Into<String>) -> Self
The deployment’s policy hook refused the action (M4A_POLICY_DENIED, 403).
pub fn forbidden(msg: impl Into<String>) -> Self
pub fn not_found(msg: impl Into<String>) -> Self
pub fn unrecognized() -> Self
pub fn bad_json(msg: impl Into<String>) -> Self
pub fn managed_account_data_type(msg: impl Into<String>) -> Self
pub fn invalid_param(msg: impl Into<String>) -> Self
pub fn duplicate_annotation() -> Self
pub fn wrong_room_keys_version(current_version: Option<i64>) -> Self
pub fn limit_exceeded(retry_after_ms: u64) -> Self
pub fn unknown(msg: impl Into<String>) -> Self
pub fn internal() -> Self